---
layout: default
title: API reference
nav_order: 5
has_children: true
permalink: /api-reference
--- 


# API reference

This page is automatically created from the `docstrings` in the code. 
Mainly [topojson.core.topology]({{site.baseurl}}/api/topojson.core.topology.html) will be of interest for the user.

All other classes and functions are used within the package. I could hide them, but maybe you find something interesting that can be used elsewhere.
